<?php

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Carousel;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Framework\Filesystem;
use Magento\Framework\View\Result\PageFactory;
use Magento\MediaStorage\Model\File\UploaderFactory;
use Magento\Store\Model\StoreManagerInterface;
use Psr\Log\LoggerInterface;

/**
 * Class CarouselList
 * @package Pinpoint\CarouselManager
 */
class Imageupload extends Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_CarouselManager::carousel';

    /**
     * @var Filesystem
     */
    protected $_filesystem;

    /**
     * @var \Magento\MediaStorage\Model\File\UploaderFactory
     */
    protected $uploader;

    /**
     * @var JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var DirectoryList
     */
    protected $directoryList;

    /**
     * @var PageFactory
     */
    protected $resultPageFactory;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * Imageupload constructor.
     * @param Context $context
     * @param Filesystem $fileSystem
     * @param UploaderFactory $uploader
     * @param JsonFactory $resultJsonFactory
     * @param StoreManagerInterface $storeManager
     * @param DirectoryList $directoryList
     */
    public function __construct(
        Context $context,
        Filesystem $fileSystem,
        UploaderFactory $uploader,
        JsonFactory $resultJsonFactory,
        StoreManagerInterface $storeManager,
        DirectoryList $directoryList,
        LoggerInterface $logger
    )
    {
        parent::__construct($context);
        $this->_filesystem = $fileSystem;
        $this->uploader = $uploader;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->storeManager = $storeManager;
        $this->directoryList = $directoryList;
        $this->logger = $logger;
    }

    /**
     * @return mixed
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultPage */
        $resultPage = $this->resultJsonFactory->create();
        if ($_FILES['block_image_upload_file']['name']) {
            try {
                $uploader = $this->uploader->create(['fileId' => 'block_image_upload_file']);
                $uploader->setAllowedExtensions(['jpg', 'jpeg', 'gif', 'png']);
                $uploader->setAllowRenameFiles(true);
                $uploader->setFilesDispersion(true);
                // get media directory
                $mediaDirectory = $this->_filesystem->getDirectoryRead(DirectoryList::MEDIA);
                // save the image to media directory
                $savePath = $mediaDirectory->getAbsolutePath() . 'pinpoint' . DIRECTORY_SEPARATOR . 'carousel' . DIRECTORY_SEPARATOR;
                $save = $uploader->save($savePath, md5(rand() . time() . uniqid()) . "." . $uploader->getFileExtension());

                $mediaFolder = $this->directoryList->getUrlPath('media');

                $save['file'] = $mediaFolder . DIRECTORY_SEPARATOR . 'pinpoint' . DIRECTORY_SEPARATOR . 'carousel' . $save['file'];
            } catch (Exception $e) {
                $this->logger->error($e->getMessage());
            }
        }
        return $resultPage->setData(['success' => true, 'file' => $save]);
    }
}
